# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AutomationModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'type': 'str',
        'presence_condition': 'str',
        'keywords': 'list[str]',
        'inactivity_condition': 'str',
        'inactivity_timeout': 'int',
        'flags': 'int',
        'all_channels': 'bool',
        'fulfillment': 'FulfillmentModel'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'presence_condition': 'presenceCondition',
        'keywords': 'keywords',
        'inactivity_condition': 'inactivityCondition',
        'inactivity_timeout': 'inactivityTimeout',
        'flags': 'flags',
        'all_channels': 'allChannels',
        'fulfillment': 'fulfillment'
    }

    def __init__(self, id=None, type=None, presence_condition=None, keywords=None, inactivity_condition=None, inactivity_timeout=None, flags=None, all_channels=None, fulfillment=None):  # noqa: E501
        """AutomationModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._type = None
        self._presence_condition = None
        self._keywords = None
        self._inactivity_condition = None
        self._inactivity_timeout = None
        self._flags = None
        self._all_channels = None
        self._fulfillment = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if presence_condition is not None:
            self.presence_condition = presence_condition
        if keywords is not None:
            self.keywords = keywords
        if inactivity_condition is not None:
            self.inactivity_condition = inactivity_condition
        if inactivity_timeout is not None:
            self.inactivity_timeout = inactivity_timeout
        if flags is not None:
            self.flags = flags
        if all_channels is not None:
            self.all_channels = all_channels
        if fulfillment is not None:
            self.fulfillment = fulfillment

    @property
    def id(self):
        """Gets the id of this AutomationModel.  # noqa: E501

        The system generated unique id for this Automation.  # noqa: E501

        :return: The id of this AutomationModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AutomationModel.

        The system generated unique id for this Automation.  # noqa: E501

        :param id: The id of this AutomationModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this AutomationModel.  # noqa: E501

        The type of the Automation.  # noqa: E501

        :return: The type of this AutomationModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AutomationModel.

        The type of the Automation.  # noqa: E501

        :param type: The type of this AutomationModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["KEYWORD", "STOP", "START", "UNMATCHED_TEXT", "INBOUND_FILE", "UNSUPPORTED_OUTBOUND_MMS", "AUTHENTICATED_SMS", "FIRST_CONTACT", "CONVERSATION_INACTIVITY", "CONVERSATION_COMPLETE", "INBOUND_FROM_BLOCKED", "CHANNEL_APP"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def presence_condition(self):
        """Gets the presence_condition of this AutomationModel.  # noqa: E501

        Defines whether the automation will apply depending on the presence and activity status of team members in the conversation with the customer.  # noqa: E501

        :return: The presence_condition of this AutomationModel.  # noqa: E501
        :rtype: str
        """
        return self._presence_condition

    @presence_condition.setter
    def presence_condition(self, presence_condition):
        """Sets the presence_condition of this AutomationModel.

        Defines whether the automation will apply depending on the presence and activity status of team members in the conversation with the customer.  # noqa: E501

        :param presence_condition: The presence_condition of this AutomationModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["NO_AGENT", "INACTIVE_AGENTS", "ALWAYS"]  # noqa: E501
        if presence_condition not in allowed_values:
            raise ValueError(
                "Invalid value for `presence_condition` ({0}), must be one of {1}"  # noqa: E501
                .format(presence_condition, allowed_values)
            )

        self._presence_condition = presence_condition

    @property
    def keywords(self):
        """Gets the keywords of this AutomationModel.  # noqa: E501

        The list of keywords to match on an incoming message. Only used when type is KEYWORD.  # noqa: E501

        :return: The keywords of this AutomationModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this AutomationModel.

        The list of keywords to match on an incoming message. Only used when type is KEYWORD.  # noqa: E501

        :param keywords: The keywords of this AutomationModel.  # noqa: E501
        :type: list[str]
        """

        self._keywords = keywords

    @property
    def inactivity_condition(self):
        """Gets the inactivity_condition of this AutomationModel.  # noqa: E501

        Whether the inactivity timer will be reset by a message from the customer, team member or both. Only used when the type is CONVERSATION_INACTIVITY.  # noqa: E501

        :return: The inactivity_condition of this AutomationModel.  # noqa: E501
        :rtype: str
        """
        return self._inactivity_condition

    @inactivity_condition.setter
    def inactivity_condition(self, inactivity_condition):
        """Sets the inactivity_condition of this AutomationModel.

        Whether the inactivity timer will be reset by a message from the customer, team member or both. Only used when the type is CONVERSATION_INACTIVITY.  # noqa: E501

        :param inactivity_condition: The inactivity_condition of this AutomationModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["TEAM_MEMBER", "CUSTOMER", "BOTH"]  # noqa: E501
        if inactivity_condition not in allowed_values:
            raise ValueError(
                "Invalid value for `inactivity_condition` ({0}), must be one of {1}"  # noqa: E501
                .format(inactivity_condition, allowed_values)
            )

        self._inactivity_condition = inactivity_condition

    @property
    def inactivity_timeout(self):
        """Gets the inactivity_timeout of this AutomationModel.  # noqa: E501

        The length of time since the last message until the conversation is deemed inactive. Only used when the type is CONVERSATION_INACTIVITY.  # noqa: E501

        :return: The inactivity_timeout of this AutomationModel.  # noqa: E501
        :rtype: int
        """
        return self._inactivity_timeout

    @inactivity_timeout.setter
    def inactivity_timeout(self, inactivity_timeout):
        """Sets the inactivity_timeout of this AutomationModel.

        The length of time since the last message until the conversation is deemed inactive. Only used when the type is CONVERSATION_INACTIVITY.  # noqa: E501

        :param inactivity_timeout: The inactivity_timeout of this AutomationModel.  # noqa: E501
        :type: int
        """

        self._inactivity_timeout = inactivity_timeout

    @property
    def flags(self):
        """Gets the flags of this AutomationModel.  # noqa: E501

        Flags further configuring the automation, depending on the automation type.  # noqa: E501

        :return: The flags of this AutomationModel.  # noqa: E501
        :rtype: int
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this AutomationModel.

        Flags further configuring the automation, depending on the automation type.  # noqa: E501

        :param flags: The flags of this AutomationModel.  # noqa: E501
        :type: int
        """

        self._flags = flags

    @property
    def all_channels(self):
        """Gets the all_channels of this AutomationModel.  # noqa: E501

        If true, this automation will apply to all channels.  # noqa: E501

        :return: The all_channels of this AutomationModel.  # noqa: E501
        :rtype: bool
        """
        return self._all_channels

    @all_channels.setter
    def all_channels(self, all_channels):
        """Sets the all_channels of this AutomationModel.

        If true, this automation will apply to all channels.  # noqa: E501

        :param all_channels: The all_channels of this AutomationModel.  # noqa: E501
        :type: bool
        """

        self._all_channels = all_channels

    @property
    def fulfillment(self):
        """Gets the fulfillment of this AutomationModel.  # noqa: E501


        :return: The fulfillment of this AutomationModel.  # noqa: E501
        :rtype: FulfillmentModel
        """
        return self._fulfillment

    @fulfillment.setter
    def fulfillment(self, fulfillment):
        """Sets the fulfillment of this AutomationModel.


        :param fulfillment: The fulfillment of this AutomationModel.  # noqa: E501
        :type: FulfillmentModel
        """

        self._fulfillment = fulfillment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AutomationModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AutomationModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.api_keys_api import APIKeysApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAPIKeysApi(unittest.TestCase):
    """APIKeysApi unit test stubs"""

    def setUp(self):
        self.api = APIKeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_api_key(self):
        """Test case for add_api_key

        Creates an API Key for an org  # noqa: E501
        """
        pass

    def test_delete_api_key(self):
        """Test case for delete_api_key

        Deletes an API Key for an org  # noqa: E501
        """
        pass

    def test_get_api_key(self):
        """Test case for get_api_key

        Gets a specific API Key for an org  # noqa: E501
        """
        pass

    def test_get_api_keys(self):
        """Test case for get_api_keys

        Gets all API Keys for an org  # noqa: E501
        """
        pass

    def test_reset_token(self):
        """Test case for reset_token

        Resets the secret for an API Key  # noqa: E501
        """
        pass

    def test_update_api_key(self):
        """Test case for update_api_key

        Updates an API Key for an org  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class IntegrationsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_integration(self, **kwargs):  # noqa: E501
        """Creates an integration  # noqa: E501

        _in snippets: platform.api.integrations.addIntegration_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_integration(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IntegrationRequestModel body:
        :return: IntegrationResponseModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_integration_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_integration_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_integration_with_http_info(self, **kwargs):  # noqa: E501
        """Creates an integration  # noqa: E501

        _in snippets: platform.api.integrations.addIntegration_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_integration_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IntegrationRequestModel body:
        :return: IntegrationResponseModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_integration" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/integrations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IntegrationResponseModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_integration(self, integration_id, **kwargs):  # noqa: E501
        """Deletes a integration  # noqa: E501

        _in snippets: platform.api.integrations.deleteIntegration_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_integration(integration_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int integration_id: (required)
        :return: DeleteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_integration_with_http_info(integration_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_integration_with_http_info(integration_id, **kwargs)  # noqa: E501
            return data

    def delete_integration_with_http_info(self, integration_id, **kwargs):  # noqa: E501
        """Deletes a integration  # noqa: E501

        _in snippets: platform.api.integrations.deleteIntegration_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_integration_with_http_info(integration_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int integration_id: (required)
        :return: DeleteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_integration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_id' is set
        if ('integration_id' not in params or
                params['integration_id'] is None):
            raise ValueError("Missing the required parameter `integration_id` when calling `delete_integration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_id' in params:
            path_params['integrationId'] = params['integration_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/integrations/{integrationId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_integration(self, integration_id, **kwargs):  # noqa: E501
        """Gets a single integration  # noqa: E501

        _in snippets: platform.api.integrations.getIntegration_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_integration(integration_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int integration_id: (required)
        :return: IntegrationResponseModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_integration_with_http_info(integration_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_integration_with_http_info(integration_id, **kwargs)  # noqa: E501
            return data

    def get_integration_with_http_info(self, integration_id, **kwargs):  # noqa: E501
        """Gets a single integration  # noqa: E501

        _in snippets: platform.api.integrations.getIntegration_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_integration_with_http_info(integration_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int integration_id: (required)
        :return: IntegrationResponseModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_integration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_id' is set
        if ('integration_id' not in params or
                params['integration_id'] is None):
            raise ValueError("Missing the required parameter `integration_id` when calling `get_integration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_id' in params:
            path_params['integrationId'] = params['integration_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/integrations/{integrationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IntegrationResponseModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_integrations(self, **kwargs):  # noqa: E501
        """Gets all the integrations  # noqa: E501

        _in snippets: platform.api.integrations.getIntegrations_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_integrations(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :return: IntegrationResponseModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_integrations_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_integrations_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_integrations_with_http_info(self, **kwargs):  # noqa: E501
        """Gets all the integrations  # noqa: E501

        _in snippets: platform.api.integrations.getIntegrations_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_integrations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :return: IntegrationResponseModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_integrations" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/integrations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IntegrationResponseModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_integration(self, integration_id, **kwargs):  # noqa: E501
        """Update an integration  # noqa: E501

        _in snippets: platform.api.integrations.updateIntegration_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_integration(integration_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int integration_id: (required)
        :param IntegrationRequestModel body:
        :return: IntegrationResponseModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_integration_with_http_info(integration_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_integration_with_http_info(integration_id, **kwargs)  # noqa: E501
            return data

    def update_integration_with_http_info(self, integration_id, **kwargs):  # noqa: E501
        """Update an integration  # noqa: E501

        _in snippets: platform.api.integrations.updateIntegration_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_integration_with_http_info(integration_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int integration_id: (required)
        :param IntegrationRequestModel body:
        :return: IntegrationResponseModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['integration_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_integration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'integration_id' is set
        if ('integration_id' not in params or
                params['integration_id'] is None):
            raise ValueError("Missing the required parameter `integration_id` when calling `update_integration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'integration_id' in params:
            path_params['integrationId'] = params['integration_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/integrations/{integrationId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='IntegrationResponseModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class DataApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_data(self, data_type, data_id, key, **kwargs):  # noqa: E501
        """Deletes one key of data for a specific data entity  # noqa: E501

        _in snippets: platform.api.data.deleteData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data(data_type, data_id, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :param str key: The key (required)
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_data_with_http_info(data_type, data_id, key, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_data_with_http_info(data_type, data_id, key, **kwargs)  # noqa: E501
            return data

    def delete_data_with_http_info(self, data_type, data_id, key, **kwargs):  # noqa: E501
        """Deletes one key of data for a specific data entity  # noqa: E501

        _in snippets: platform.api.data.deleteData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_with_http_info(data_type, data_id, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :param str key: The key (required)
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_type', 'data_id', 'key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_type' is set
        if ('data_type' not in params or
                params['data_type'] is None):
            raise ValueError("Missing the required parameter `data_type` when calling `delete_data`")  # noqa: E501
        # verify the required parameter 'data_id' is set
        if ('data_id' not in params or
                params['data_id'] is None):
            raise ValueError("Missing the required parameter `data_id` when calling `delete_data`")  # noqa: E501
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `delete_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_type' in params:
            path_params['dataType'] = params['data_type']  # noqa: E501
        if 'data_id' in params:
            path_params['dataId'] = params['data_id']  # noqa: E501
        if 'key' in params:
            path_params['key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/data/{dataType}/{dataId}/keys/{key}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, str)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data(self, data_type, data_id, **kwargs):  # noqa: E501
        """Gets all the data for a specific data entity  # noqa: E501

        _in snippets: platform.api.data.getData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data(data_type, data_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_data_with_http_info(data_type, data_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_data_with_http_info(data_type, data_id, **kwargs)  # noqa: E501
            return data

    def get_data_with_http_info(self, data_type, data_id, **kwargs):  # noqa: E501
        """Gets all the data for a specific data entity  # noqa: E501

        _in snippets: platform.api.data.getData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_with_http_info(data_type, data_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_type', 'data_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_type' is set
        if ('data_type' not in params or
                params['data_type'] is None):
            raise ValueError("Missing the required parameter `data_type` when calling `get_data`")  # noqa: E501
        # verify the required parameter 'data_id' is set
        if ('data_id' not in params or
                params['data_id'] is None):
            raise ValueError("Missing the required parameter `data_id` when calling `get_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_type' in params:
            path_params['dataType'] = params['data_type']  # noqa: E501
        if 'data_id' in params:
            path_params['dataId'] = params['data_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/data/{dataType}/{dataId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, str)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data_by_key(self, data_type, data_id, key, **kwargs):  # noqa: E501
        """Gets one key of data for a specific data entity  # noqa: E501

        _in snippets: platform.api.data.getDataByKey_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_by_key(data_type, data_id, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :param str key: The key (required)
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_data_by_key_with_http_info(data_type, data_id, key, **kwargs)  # noqa: E501
        else:
            (data) = self.get_data_by_key_with_http_info(data_type, data_id, key, **kwargs)  # noqa: E501
            return data

    def get_data_by_key_with_http_info(self, data_type, data_id, key, **kwargs):  # noqa: E501
        """Gets one key of data for a specific data entity  # noqa: E501

        _in snippets: platform.api.data.getDataByKey_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_by_key_with_http_info(data_type, data_id, key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :param str key: The key (required)
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_type', 'data_id', 'key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data_by_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_type' is set
        if ('data_type' not in params or
                params['data_type'] is None):
            raise ValueError("Missing the required parameter `data_type` when calling `get_data_by_key`")  # noqa: E501
        # verify the required parameter 'data_id' is set
        if ('data_id' not in params or
                params['data_id'] is None):
            raise ValueError("Missing the required parameter `data_id` when calling `get_data_by_key`")  # noqa: E501
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `get_data_by_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_type' in params:
            path_params['dataType'] = params['data_type']  # noqa: E501
        if 'data_id' in params:
            path_params['dataId'] = params['data_id']  # noqa: E501
        if 'key' in params:
            path_params['key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/data/{dataType}/{dataId}/keys/{key}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, str)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data_default(self, key, **kwargs):  # noqa: E501
        """Get the default values for a specific customer data key  # noqa: E501

        _in snippets: platform.api.data.getDataDefault_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_default(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: The key (required)
        :return: DataDefaultModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_data_default_with_http_info(key, **kwargs)  # noqa: E501
        else:
            (data) = self.get_data_default_with_http_info(key, **kwargs)  # noqa: E501
            return data

    def get_data_default_with_http_info(self, key, **kwargs):  # noqa: E501
        """Get the default values for a specific customer data key  # noqa: E501

        _in snippets: platform.api.data.getDataDefault_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_default_with_http_info(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: The key (required)
        :return: DataDefaultModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data_default" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `get_data_default`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'key' in params:
            path_params['key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/data/defaults/{key}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DataDefaultModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data_defaults(self, **kwargs):  # noqa: E501
        """Get the default values for customer data keys  # noqa: E501

        _in snippets: platform.api.data.getDataDefaults_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_defaults(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :return: DataDefaultModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_data_defaults_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_data_defaults_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_data_defaults_with_http_info(self, **kwargs):  # noqa: E501
        """Get the default values for customer data keys  # noqa: E501

        _in snippets: platform.api.data.getDataDefaults_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_defaults_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :return: DataDefaultModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data_defaults" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/data/defaults', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DataDefaultModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_data(self, data_type, data_id, **kwargs):  # noqa: E501
        """Sets all the data for a specific data entity (unmentioned keys are removed)  # noqa: E501

        _in snippets: platform.api.data.setData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data(data_type, data_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :param dict(str, str) body:
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_data_with_http_info(data_type, data_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_data_with_http_info(data_type, data_id, **kwargs)  # noqa: E501
            return data

    def set_data_with_http_info(self, data_type, data_id, **kwargs):  # noqa: E501
        """Sets all the data for a specific data entity (unmentioned keys are removed)  # noqa: E501

        _in snippets: platform.api.data.setData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data_with_http_info(data_type, data_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :param dict(str, str) body:
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_type', 'data_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_type' is set
        if ('data_type' not in params or
                params['data_type'] is None):
            raise ValueError("Missing the required parameter `data_type` when calling `set_data`")  # noqa: E501
        # verify the required parameter 'data_id' is set
        if ('data_id' not in params or
                params['data_id'] is None):
            raise ValueError("Missing the required parameter `data_id` when calling `set_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_type' in params:
            path_params['dataType'] = params['data_type']  # noqa: E501
        if 'data_id' in params:
            path_params['dataId'] = params['data_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/data/{dataType}/{dataId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, str)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_data_default(self, key, **kwargs):  # noqa: E501
        """Set the default value for a specific customer data key  # noqa: E501

        _in snippets: platform.api.data.setDataDefault_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data_default(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: The key (required)
        :param DataDefaultModel body:
        :return: DataDefaultModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_data_default_with_http_info(key, **kwargs)  # noqa: E501
        else:
            (data) = self.set_data_default_with_http_info(key, **kwargs)  # noqa: E501
            return data

    def set_data_default_with_http_info(self, key, **kwargs):  # noqa: E501
        """Set the default value for a specific customer data key  # noqa: E501

        _in snippets: platform.api.data.setDataDefault_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data_default_with_http_info(key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str key: The key (required)
        :param DataDefaultModel body:
        :return: DataDefaultModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['key', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_data_default" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'key' is set
        if ('key' not in params or
                params['key'] is None):
            raise ValueError("Missing the required parameter `key` when calling `set_data_default`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'key' in params:
            path_params['key'] = params['key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/data/defaults/{key}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DataDefaultModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_data(self, data_type, data_id, **kwargs):  # noqa: E501
        """Updates data for a specific data entity (does not modify unmentioned keys)  # noqa: E501

        _in snippets: platform.api.data.updateData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_data(data_type, data_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :param dict(str, str) body:
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_data_with_http_info(data_type, data_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_data_with_http_info(data_type, data_id, **kwargs)  # noqa: E501
            return data

    def update_data_with_http_info(self, data_type, data_id, **kwargs):  # noqa: E501
        """Updates data for a specific data entity (does not modify unmentioned keys)  # noqa: E501

        _in snippets: platform.api.data.updateData_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_data_with_http_info(data_type, data_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_type: The type of data store being accessed, allowable values are customer,agent,org,schema,channel,app (required)
        :param str data_id: The apiId or internal id (required)
        :param dict(str, str) body:
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_type', 'data_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_type' is set
        if ('data_type' not in params or
                params['data_type'] is None):
            raise ValueError("Missing the required parameter `data_type` when calling `update_data`")  # noqa: E501
        # verify the required parameter 'data_id' is set
        if ('data_id' not in params or
                params['data_id'] is None):
            raise ValueError("Missing the required parameter `data_id` when calling `update_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_type' in params:
            path_params['dataType'] = params['data_type']  # noqa: E501
        if 'data_id' in params:
            path_params['dataId'] = params['data_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/data/{dataType}/{dataId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, str)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BulkActionRetargetModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'bulk_action_id': 'int',
        'retarget_bulk_action_id': 'int',
        'metric': 'str',
        'metric_info': 'str',
        'team_member_id': 'int',
        'variant_id': 'int'
    }

    attribute_map = {
        'id': 'id',
        'bulk_action_id': 'bulkActionId',
        'retarget_bulk_action_id': 'retargetBulkActionId',
        'metric': 'metric',
        'metric_info': 'metricInfo',
        'team_member_id': 'teamMemberId',
        'variant_id': 'variantId'
    }

    def __init__(self, id=None, bulk_action_id=None, retarget_bulk_action_id=None, metric=None, metric_info=None, team_member_id=None, variant_id=None):  # noqa: E501
        """BulkActionRetargetModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._bulk_action_id = None
        self._retarget_bulk_action_id = None
        self._metric = None
        self._metric_info = None
        self._team_member_id = None
        self._variant_id = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if bulk_action_id is not None:
            self.bulk_action_id = bulk_action_id
        self.retarget_bulk_action_id = retarget_bulk_action_id
        self.metric = metric
        if metric_info is not None:
            self.metric_info = metric_info
        if team_member_id is not None:
            self.team_member_id = team_member_id
        if variant_id is not None:
            self.variant_id = variant_id

    @property
    def id(self):
        """Gets the id of this BulkActionRetargetModel.  # noqa: E501

        The system generated unique id for this retarget info.  # noqa: E501

        :return: The id of this BulkActionRetargetModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BulkActionRetargetModel.

        The system generated unique id for this retarget info.  # noqa: E501

        :param id: The id of this BulkActionRetargetModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def bulk_action_id(self):
        """Gets the bulk_action_id of this BulkActionRetargetModel.  # noqa: E501

        The system generated unique id for newly created bulk action.  # noqa: E501

        :return: The bulk_action_id of this BulkActionRetargetModel.  # noqa: E501
        :rtype: int
        """
        return self._bulk_action_id

    @bulk_action_id.setter
    def bulk_action_id(self, bulk_action_id):
        """Sets the bulk_action_id of this BulkActionRetargetModel.

        The system generated unique id for newly created bulk action.  # noqa: E501

        :param bulk_action_id: The bulk_action_id of this BulkActionRetargetModel.  # noqa: E501
        :type: int
        """

        self._bulk_action_id = bulk_action_id

    @property
    def retarget_bulk_action_id(self):
        """Gets the retarget_bulk_action_id of this BulkActionRetargetModel.  # noqa: E501

        Id of the bulk action to retarget.  # noqa: E501

        :return: The retarget_bulk_action_id of this BulkActionRetargetModel.  # noqa: E501
        :rtype: int
        """
        return self._retarget_bulk_action_id

    @retarget_bulk_action_id.setter
    def retarget_bulk_action_id(self, retarget_bulk_action_id):
        """Sets the retarget_bulk_action_id of this BulkActionRetargetModel.

        Id of the bulk action to retarget.  # noqa: E501

        :param retarget_bulk_action_id: The retarget_bulk_action_id of this BulkActionRetargetModel.  # noqa: E501
        :type: int
        """
        if retarget_bulk_action_id is None:
            raise ValueError("Invalid value for `retarget_bulk_action_id`, must not be `None`")  # noqa: E501

        self._retarget_bulk_action_id = retarget_bulk_action_id

    @property
    def metric(self):
        """Gets the metric of this BulkActionRetargetModel.  # noqa: E501

        The metric being retargeted.  # noqa: E501

        :return: The metric of this BulkActionRetargetModel.  # noqa: E501
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this BulkActionRetargetModel.

        The metric being retargeted.  # noqa: E501

        :param metric: The metric of this BulkActionRetargetModel.  # noqa: E501
        :type: str
        """
        if metric is None:
            raise ValueError("Invalid value for `metric`, must not be `None`")  # noqa: E501
        allowed_values = ["ALL", "DELIVERED", "SKIPPED", "QUEUED", "LOCKED", "CANCELLED", "ERROR_ANY", "ENGAGED_INSTANT_APP_OPENED", "ENGAGED_SMART_LINK_CLICKED", "ENGAGED_REPLIED", "ENGAGED_REPLIED_TO_REPLY", "NO_RESPONSE", "OPT_OUT", "RESOLUTION", "ERROR_SPECIFIC", "ADDED_TAG", "PROCESSING_PENDING"]  # noqa: E501
        if metric not in allowed_values:
            raise ValueError(
                "Invalid value for `metric` ({0}), must be one of {1}"  # noqa: E501
                .format(metric, allowed_values)
            )

        self._metric = metric

    @property
    def metric_info(self):
        """Gets the metric_info of this BulkActionRetargetModel.  # noqa: E501

        The metric info, if any.  # noqa: E501

        :return: The metric_info of this BulkActionRetargetModel.  # noqa: E501
        :rtype: str
        """
        return self._metric_info

    @metric_info.setter
    def metric_info(self, metric_info):
        """Sets the metric_info of this BulkActionRetargetModel.

        The metric info, if any.  # noqa: E501

        :param metric_info: The metric_info of this BulkActionRetargetModel.  # noqa: E501
        :type: str
        """

        self._metric_info = metric_info

    @property
    def team_member_id(self):
        """Gets the team_member_id of this BulkActionRetargetModel.  # noqa: E501

        Id of the team member being retargeted, if any.  # noqa: E501

        :return: The team_member_id of this BulkActionRetargetModel.  # noqa: E501
        :rtype: int
        """
        return self._team_member_id

    @team_member_id.setter
    def team_member_id(self, team_member_id):
        """Sets the team_member_id of this BulkActionRetargetModel.

        Id of the team member being retargeted, if any.  # noqa: E501

        :param team_member_id: The team_member_id of this BulkActionRetargetModel.  # noqa: E501
        :type: int
        """

        self._team_member_id = team_member_id

    @property
    def variant_id(self):
        """Gets the variant_id of this BulkActionRetargetModel.  # noqa: E501

        Id of the variant being retargeted, if any.  # noqa: E501

        :return: The variant_id of this BulkActionRetargetModel.  # noqa: E501
        :rtype: int
        """
        return self._variant_id

    @variant_id.setter
    def variant_id(self, variant_id):
        """Sets the variant_id of this BulkActionRetargetModel.

        Id of the variant being retargeted, if any.  # noqa: E501

        :param variant_id: The variant_id of this BulkActionRetargetModel.  # noqa: E501
        :type: int
        """

        self._variant_id = variant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BulkActionRetargetModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BulkActionRetargetModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.tag_groups_api import TagGroupsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestTagGroupsApi(unittest.TestCase):
    """TagGroupsApi unit test stubs"""

    def setUp(self):
        self.api = TagGroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_tag_group(self):
        """Test case for add_tag_group

        Creates a tag group  # noqa: E501
        """
        pass

    def test_add_tag_to_tag_group(self):
        """Test case for add_tag_to_tag_group

        Add a tag to a tag group  # noqa: E501
        """
        pass

    def test_delete_tag_group(self):
        """Test case for delete_tag_group

        Deletes a tag group  # noqa: E501
        """
        pass

    def test_get_tag_group(self):
        """Test case for get_tag_group

        Gets the details of a specific tag group  # noqa: E501
        """
        pass

    def test_get_tag_groups(self):
        """Test case for get_tag_groups

        Gets all tag groups  # noqa: E501
        """
        pass

    def test_get_tag_in_tag_groups(self):
        """Test case for get_tag_in_tag_groups

        Gets all tags in a group  # noqa: E501
        """
        pass

    def test_remove_tag_from_tag_group(self):
        """Test case for remove_tag_from_tag_group

        Remove a tag from a tag group  # noqa: E501
        """
        pass

    def test_update_tag_group(self):
        """Test case for update_tag_group

        Modifies a tag group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BotIntentModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'name': 'str',
        'phrases': 'list[BotIntentPhraseModel]',
        'queries': 'list[str]',
        'fulfillment_model': 'BotFulfillmentModel',
        'active': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'name': 'name',
        'phrases': 'phrases',
        'queries': 'queries',
        'fulfillment_model': 'fulfillmentModel',
        'active': 'active'
    }

    def __init__(self, type=None, name=None, phrases=None, queries=None, fulfillment_model=None, active=None):  # noqa: E501
        """BotIntentModel - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._name = None
        self._phrases = None
        self._queries = None
        self._fulfillment_model = None
        self._active = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if name is not None:
            self.name = name
        if phrases is not None:
            self.phrases = phrases
        if queries is not None:
            self.queries = queries
        if fulfillment_model is not None:
            self.fulfillment_model = fulfillment_model
        if active is not None:
            self.active = active

    @property
    def type(self):
        """Gets the type of this BotIntentModel.  # noqa: E501


        :return: The type of this BotIntentModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BotIntentModel.


        :param type: The type of this BotIntentModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["CUSTOM", "UNKNOWN", "KEYWORD", "BOOT", "WRONG_LANGUAGE", "GARBAGE", "NO_MATCH", "IGNORE", "UPLOAD", "STOP", "START"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def name(self):
        """Gets the name of this BotIntentModel.  # noqa: E501


        :return: The name of this BotIntentModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BotIntentModel.


        :param name: The name of this BotIntentModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def phrases(self):
        """Gets the phrases of this BotIntentModel.  # noqa: E501


        :return: The phrases of this BotIntentModel.  # noqa: E501
        :rtype: list[BotIntentPhraseModel]
        """
        return self._phrases

    @phrases.setter
    def phrases(self, phrases):
        """Sets the phrases of this BotIntentModel.


        :param phrases: The phrases of this BotIntentModel.  # noqa: E501
        :type: list[BotIntentPhraseModel]
        """

        self._phrases = phrases

    @property
    def queries(self):
        """Gets the queries of this BotIntentModel.  # noqa: E501


        :return: The queries of this BotIntentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._queries

    @queries.setter
    def queries(self, queries):
        """Sets the queries of this BotIntentModel.


        :param queries: The queries of this BotIntentModel.  # noqa: E501
        :type: list[str]
        """

        self._queries = queries

    @property
    def fulfillment_model(self):
        """Gets the fulfillment_model of this BotIntentModel.  # noqa: E501


        :return: The fulfillment_model of this BotIntentModel.  # noqa: E501
        :rtype: BotFulfillmentModel
        """
        return self._fulfillment_model

    @fulfillment_model.setter
    def fulfillment_model(self, fulfillment_model):
        """Sets the fulfillment_model of this BotIntentModel.


        :param fulfillment_model: The fulfillment_model of this BotIntentModel.  # noqa: E501
        :type: BotFulfillmentModel
        """

        self._fulfillment_model = fulfillment_model

    @property
    def active(self):
        """Gets the active of this BotIntentModel.  # noqa: E501


        :return: The active of this BotIntentModel.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this BotIntentModel.


        :param active: The active of this BotIntentModel.  # noqa: E501
        :type: bool
        """

        self._active = active

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BotIntentModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BotIntentModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class AnalyticsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_agent_activity_report(self, **kwargs):  # noqa: E501
        """Get the Agent Activity Report for the org.  # noqa: E501

        _in snippets: platform.api.analytics.getAgentActivityReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_agent_activity_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param bool include_deleted:
        :return: list[AnalyticsAgentActivityReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_agent_activity_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_agent_activity_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_agent_activity_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Agent Activity Report for the org.  # noqa: E501

        _in snippets: platform.api.analytics.getAgentActivityReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_agent_activity_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param bool include_deleted:
        :return: list[AnalyticsAgentActivityReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window', 'include_deleted']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_agent_activity_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'include_deleted' in params:
            query_params.append(('include_deleted', params['include_deleted']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/agent_activity_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsAgentActivityReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_agent_activity_report_for_channel(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Agent Activity Report for a specific channel.  # noqa: E501

        _in snippets: platform.api.analytics.getAgentActivityReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_agent_activity_report_for_channel(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param bool include_deleted:
        :return: list[AnalyticsAgentActivityReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_agent_activity_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_agent_activity_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def get_agent_activity_report_for_channel_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Agent Activity Report for a specific channel.  # noqa: E501

        _in snippets: platform.api.analytics.getAgentActivityReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_agent_activity_report_for_channel_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param bool include_deleted:
        :return: list[AnalyticsAgentActivityReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id', 'start_time', 'end_time', 'time_window', 'include_deleted']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_agent_activity_report_for_channel" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_agent_activity_report_for_channel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'include_deleted' in params:
            query_params.append(('include_deleted', params['include_deleted']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/agent_activity_report/{orgChannelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsAgentActivityReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_channel_report(self, **kwargs):  # noqa: E501
        """Get the Channel Report for the org.  # noqa: E501

        _in snippets: platform.api.analytics.getChannelReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_channel_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsChannelReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_channel_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_channel_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_channel_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Channel Report for the org.  # noqa: E501

        _in snippets: platform.api.analytics.getChannelReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_channel_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsChannelReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_channel_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/channel_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsChannelReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_contact_action_report(self, **kwargs):  # noqa: E501
        """Get the Contact Action Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getContactActionReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_contact_action_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsBulkActionReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_contact_action_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_contact_action_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_contact_action_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Contact Action Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getContactActionReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_contact_action_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsBulkActionReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_contact_action_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/contact_action_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsBulkActionReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_custom_counters_report(self, **kwargs):  # noqa: E501
        """Get the Custom Counters Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getCustomCountersReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_counters_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsCustomCountersReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_custom_counters_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_custom_counters_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_custom_counters_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Custom Counters Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getCustomCountersReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_counters_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsCustomCountersReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_counters_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/custom_counters_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsCustomCountersReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_custom_counters_report_for_schema(self, schema_id, **kwargs):  # noqa: E501
        """Get the Custom Counters Report for a specific schemaId  # noqa: E501

        _in snippets: platform.api.analytics.getCustomCountersReportForSchema_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_counters_report_for_schema(schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int schema_id: The numeric schemaId (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsCustomCountersReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_custom_counters_report_for_schema_with_http_info(schema_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_custom_counters_report_for_schema_with_http_info(schema_id, **kwargs)  # noqa: E501
            return data

    def get_custom_counters_report_for_schema_with_http_info(self, schema_id, **kwargs):  # noqa: E501
        """Get the Custom Counters Report for a specific schemaId  # noqa: E501

        _in snippets: platform.api.analytics.getCustomCountersReportForSchema_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_custom_counters_report_for_schema_with_http_info(schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int schema_id: The numeric schemaId (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsCustomCountersReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['schema_id', 'start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_custom_counters_report_for_schema" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'schema_id' is set
        if ('schema_id' not in params or
                params['schema_id'] is None):
            raise ValueError("Missing the required parameter `schema_id` when calling `get_custom_counters_report_for_schema`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'schema_id' in params:
            path_params['schemaId'] = params['schema_id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/custom_counters_report/{schemaId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsCustomCountersReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_customer_engagement_report(self, **kwargs):  # noqa: E501
        """Get the Customer Engagement Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getCustomerEngagementReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_engagement_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsCustomerEngagementReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_customer_engagement_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_customer_engagement_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_customer_engagement_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Customer Engagement Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getCustomerEngagementReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_engagement_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsCustomerEngagementReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_customer_engagement_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/customer_engagement_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsCustomerEngagementReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_customer_engagement_report_for_channel(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Customer Engagement Report for a specific channel  # noqa: E501

        _in snippets: platform.api.analytics.getCustomerEngagementReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_engagement_report_for_channel(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsCustomerEngagementReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_customer_engagement_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_customer_engagement_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def get_customer_engagement_report_for_channel_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Customer Engagement Report for a specific channel  # noqa: E501

        _in snippets: platform.api.analytics.getCustomerEngagementReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_customer_engagement_report_for_channel_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsCustomerEngagementReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id', 'start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_customer_engagement_report_for_channel" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_customer_engagement_report_for_channel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/customer_engagement_report/{orgChannelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsCustomerEngagementReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_error_report(self, **kwargs):  # noqa: E501
        """Get the Error Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getErrorReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_error_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsErrorReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_error_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_error_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_error_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Error Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getErrorReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_error_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsErrorReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_error_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/error_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsErrorReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_instant_app_report(self, **kwargs):  # noqa: E501
        """Get the Instant App Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getInstantAppReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_app_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsInstantAppReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_instant_app_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_instant_app_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_instant_app_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Instant App Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getInstantAppReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_app_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsInstantAppReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_instant_app_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/instant_app_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsInstantAppReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_instant_app_report_for_schema(self, schema_id, **kwargs):  # noqa: E501
        """Get the Instant App Report for a specific schema  # noqa: E501

        _in snippets: platform.api.analytics.getInstantAppReportForSchema_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_app_report_for_schema(schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int schema_id: The numeric schemaId (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsInstantAppReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_instant_app_report_for_schema_with_http_info(schema_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_instant_app_report_for_schema_with_http_info(schema_id, **kwargs)  # noqa: E501
            return data

    def get_instant_app_report_for_schema_with_http_info(self, schema_id, **kwargs):  # noqa: E501
        """Get the Instant App Report for a specific schema  # noqa: E501

        _in snippets: platform.api.analytics.getInstantAppReportForSchema_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_app_report_for_schema_with_http_info(schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int schema_id: The numeric schemaId (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsInstantAppReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['schema_id', 'start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_instant_app_report_for_schema" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'schema_id' is set
        if ('schema_id' not in params or
                params['schema_id'] is None):
            raise ValueError("Missing the required parameter `schema_id` when calling `get_instant_app_report_for_schema`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'schema_id' in params:
            path_params['schemaId'] = params['schema_id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/instant_app_report/{schemaId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsInstantAppReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_instant_app_schema_report(self, schema_id, **kwargs):  # noqa: E501
        """Get the Instant App Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getInstantAppSchemaReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_app_schema_report(schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int schema_id: The numeric schemaId (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsInstantAppSchemaReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_instant_app_schema_report_with_http_info(schema_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_instant_app_schema_report_with_http_info(schema_id, **kwargs)  # noqa: E501
            return data

    def get_instant_app_schema_report_with_http_info(self, schema_id, **kwargs):  # noqa: E501
        """Get the Instant App Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getInstantAppSchemaReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_instant_app_schema_report_with_http_info(schema_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int schema_id: The numeric schemaId (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsInstantAppSchemaReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['schema_id', 'start_time', 'end_time', 'time_window']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_instant_app_schema_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'schema_id' is set
        if ('schema_id' not in params or
                params['schema_id'] is None):
            raise ValueError("Missing the required parameter `schema_id` when calling `get_instant_app_schema_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'schema_id' in params:
            path_params['schemaId'] = params['schema_id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/instant_app_schema_report/{schemaId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsInstantAppSchemaReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_kpi_report(self, **kwargs):  # noqa: E501
        """Get the KPI Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getKpiReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_kpi_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsKpiReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_kpi_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_kpi_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_kpi_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the KPI Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getKpiReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_kpi_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: list[AnalyticsKpiReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_kpi_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/kpi_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsKpiReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_messaging_report(self, **kwargs):  # noqa: E501
        """Get the Messaging Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getMessagingReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_messaging_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: AnalyticsMessagingReportModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_messaging_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_messaging_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_messaging_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Messaging Report for the org  # noqa: E501

        _in snippets: platform.api.analytics.getMessagingReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_messaging_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: AnalyticsMessagingReportModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_messaging_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/messaging_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AnalyticsMessagingReportModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_messaging_report_for_channel(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Messaging Report for a specific channel  # noqa: E501

        _in snippets: platform.api.analytics.getMessagingReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_messaging_report_for_channel(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: AnalyticsMessagingReportModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_messaging_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_messaging_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def get_messaging_report_for_channel_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Messaging Report for a specific channel  # noqa: E501

        _in snippets: platform.api.analytics.getMessagingReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_messaging_report_for_channel_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param str group_by_time:
        :return: AnalyticsMessagingReportModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id', 'start_time', 'end_time', 'time_window', 'group_by_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_messaging_report_for_channel" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_messaging_report_for_channel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'group_by_time' in params:
            query_params.append(('groupByTime', params['group_by_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/messaging_report/{orgChannelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AnalyticsMessagingReportModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_opt_out_report(self, **kwargs):  # noqa: E501
        """Get the Opt-Out Report for the org.  # noqa: E501

        _in snippets: platform.api.analytics.getOptOutReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_opt_out_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsOptOutReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_opt_out_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_opt_out_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_opt_out_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Opt-Out Report for the org.  # noqa: E501

        _in snippets: platform.api.analytics.getOptOutReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_opt_out_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsOptOutReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_opt_out_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/opt_out_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsOptOutReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_opt_out_report_for_channel(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Opt-Out Report for a specific channel  # noqa: E501

        _in snippets: platform.api.analytics.getOptOutReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_opt_out_report_for_channel(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsOptOutReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_opt_out_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_opt_out_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def get_opt_out_report_for_channel_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Opt-Out Report for a specific channel  # noqa: E501

        _in snippets: platform.api.analytics.getOptOutReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_opt_out_report_for_channel_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :return: list[AnalyticsOptOutReportModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id', 'start_time', 'end_time', 'time_window']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_opt_out_report_for_channel" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_opt_out_report_for_channel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/opt_out_report/{orgChannelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsOptOutReportModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_org_activity_report(self, **kwargs):  # noqa: E501
        """Get the Org Activity Report totals.  # noqa: E501

        _in snippets: platform.api.analytics.getOrgActivityReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_activity_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param bool include_deleted:
        :return: AnalyticsOrgActivityReportModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_org_activity_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_org_activity_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_org_activity_report_with_http_info(self, **kwargs):  # noqa: E501
        """Get the Org Activity Report totals.  # noqa: E501

        _in snippets: platform.api.analytics.getOrgActivityReport_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_activity_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param bool include_deleted:
        :return: AnalyticsOrgActivityReportModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_time', 'end_time', 'time_window', 'include_deleted']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_org_activity_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'include_deleted' in params:
            query_params.append(('include_deleted', params['include_deleted']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/org_activity_report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AnalyticsOrgActivityReportModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_org_activity_report_for_channel(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Org Activity Report totals for a specific channel.  # noqa: E501

        _in snippets: platform.api.analytics.getOrgActivityReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_activity_report_for_channel(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param bool include_deleted:
        :return: AnalyticsOrgActivityReportModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_org_activity_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_org_activity_report_for_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def get_org_activity_report_for_channel_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """Get the Org Activity Report totals for a specific channel.  # noqa: E501

        _in snippets: platform.api.analytics.getOrgActivityReportForChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_activity_report_for_channel_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int org_channel_id: The apiId or internal id (required)
        :param int start_time:
        :param int end_time:
        :param str time_window:
        :param bool include_deleted:
        :return: AnalyticsOrgActivityReportModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id', 'start_time', 'end_time', 'time_window', 'include_deleted']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_org_activity_report_for_channel" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_org_activity_report_for_channel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))  # noqa: E501
        if 'time_window' in params:
            query_params.append(('timeWindow', params['time_window']))  # noqa: E501
        if 'include_deleted' in params:
            query_params.append(('include_deleted', params['include_deleted']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/analytics/org_activity_report/{orgChannelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AnalyticsOrgActivityReportModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
